{%  load i18n %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
</head>
<body>
<p>{% translate "Hello"%}, {{ customer_name }}</p>
<p>{% blocktranslate %}Thank you for use the <strong>CADEFIHUILA's</strong> transactional portal. To finish your registration process, please use the code below:{% endblocktranslate %}</p>
<p>
    <h2 style="text-align: center;">{{ customer_code }}</h2>
</p>
<p>{% blocktranslate %}The code is valid for {{ code_timeout }} minutes.{% endblocktranslate %}</p>
<p>
    <label style="font-size: 8px;">
        {% blocktranslate %}This email was generated automatically at {{ email_datetime }} with id {{ email_id }}. Please do not answer it.{% endblocktranslate %}
    </label>
</p>
</body>
</html>